from arxivAssistant.app import ArxivApp


def main() -> None:

    ArxivApp.run(title="Arxiv Assistant")
